@@ -77,12 +77,60 @@ storage.get(DEFAULT_EXTENSION_SETTINGS, function (items) {
 // ------------------------------------------------------------------------
 //
 function loadBreezeScrollBars() {
-    if (!IS_FIREFOX) {
-        var linkTag = document.createElement("link");
-        linkTag.rel = "stylesheet";
-        linkTag.href =  chrome.extension.getURL("breeze-scroll-bars.css");
-        (document.head || document.documentElement).appendChild(linkTag);
+    if (IS_FIREFOX) {
+        return;
     }
+
+    if (!document.head) {
+        return;
+    }
+
+    // You cannot access cssRules for <link rel="stylesheet" ..> on a different domain.
+    // Since our chrome-extension:// URL for a stylesheet would be, this can
+    // lead to problems in e.g modernizr, so include the <style> inline instead.
+    // "Failed to read the 'cssRules' property from 'CSSStyleSheet': Cannot access rules"
+    var styleTag = document.createElement("style");
+    styleTag.appendChild(document.createTextNode(`
+::-webkit-scrollbar {
+    /* we'll add padding as "border" in the thumb*/
+    height: 20px;
+    width: 20px;
+    background: white;
+}
+
+::-webkit-scrollbar-track {
+    border-radius: 20px;
+    border: 7px solid white; /* FIXME why doesn't "transparent" work here?! */
+    background-color: white;
+    width: 6px !important; /* 20px scrollbar - 2 * 7px border */
+    box-sizing: content-box;
+}
+::-webkit-scrollbar-track:hover {
+    background-color: #BFC0C2;
+}
+
+::-webkit-scrollbar-thumb {
+    background-color: #3DAEE9; /* default blue breeze color */
+    border: 7px solid transparent;
+    border-radius: 20px;
+    background-clip: content-box;
+    width: 6px !important; /* 20px scrollbar - 2 * 7px border */
+    box-sizing: content-box;
+    min-height: 30px;
+}
+::-webkit-scrollbar-thumb:window-inactive {
+   background-color: #949699; /* when window is inactive it's gray */
+}
+::-webkit-scrollbar-thumb:hover {
+    background-color: #93CEE9; /* hovered is a lighter blue */
+}
+
+::-webkit-scrollbar-corner {
+    background-color: white; /* FIXME why doesn't "transparent" work here?! */
+}
+    `));
+
+    document.head.appendChild(styleTag);
 }
 
 
@@ -102,6 +150,9 @@ var mediaSessionsTransferDivId ='xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/
 var mediaSessionsClassName = "f" + mediaSessionsTransferDivId.replace(/-/g, "");
 
 var activePlayer;
+// When a player has no duration yet, we'll wait for it becoming known
+// to determine whether to ignore it (short sound) or make it active
+var pendingActivePlayer;
 var playerMetadata = {};
 var playerCallbacks = [];
 
@@ -219,9 +270,19 @@ function playerPaused(player) {
 }
 
 function setPlayerActive(player) {
+    if (isNaN(player.duration)) {
+        // Ignore this player for now until we know a duration
+        // In durationchange event handler we'll check for this and end up here again
+        pendingActivePlayer = player;
+        return;
+    }
+
+    pendingActivePlayer = undefined;
+
     // Ignore short sounds, they are most likely a chat notification sound
-    // but still allow when undetermined (e.g. video stream)
-    if (!isNaN(player.duration) && player.duration > 0 && player.duration < 5) {
+    // A stream has a duration of Infinity
+    // Note that "NaN" is also not finite but we already returned earlier for that
+    if (isFinite(player.duration) && player.duration > 0 && player.duration < 5) {
         return;
     }
 
@@ -244,6 +305,7 @@ function setPlayerActive(player) {
 
 function sendPlayerGone() {
     activePlayer = undefined;
+    pendingActivePlayer = undefined;
     playerMetadata = {};
     playerCallbacks = [];
     sendMessage("mpris", "gone");
@@ -309,6 +371,12 @@ function registerPlayer(player) {
 
     // TODO use player.seekable for determining whether we can seek?
     player.addEventListener("durationchange", function () {
+        // Deferred active due to unknown duration
+        if (pendingActivePlayer == player) {
+            setPlayerActive(pendingActivePlayer);
+            return;
+        }
+
         sendPlayerInfo(player, "duration", {
             duration: player.duration
         });
@@ -520,7 +588,7 @@ function loadMediaSessionsShim() {
                     get: function() { return ${mediaSessionsClassName}.metadata; },
                     set: function(newValue) {
                         ${mediaSessionsClassName}.metadata = newValue;
-                        ${mediaSessionsClassName}.sendMessage("metadata", newValue.data);
+                        ${mediaSessionsClassName}.sendMessage("metadata", newValue ? newValue.data : null);
                     }
                 });
                 Object.defineProperty(navigator.mediaSession, "playbackState", {
@@ -563,6 +631,21 @@ function loadMediaSessionsShim() {
             }
         `);
 
+        // We also briefly add items created as new Audio() to the DOM so we can control it
+        // similar to the document.createElement hack above
+        executeScript(`function() {
+                var oldAudio = window.Audio;
+                window.Audio = function () {
+                    var createdAudio = new (Function.prototype.bind.apply(oldAudio, arguments));
+
+                    (document.head || document.documentElement).appendChild(createdAudio);
+                    createdAudio.parentNode.removeChild(createdAudio);
+
+                    return createdAudio;
+                };
+            }
+        `);
+
         // now the fun part of getting the stuff from our page back into our extension...
         // cannot access extensions from innocent page JS for security
         var transferItem = document.createElement("div");
